==> xwiki-platform-security-api-9.11-rc-1-sources.jar: org/xwiki/security/internal/XWikiBridge.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.security.internal;

import org.xwiki.component.annotation.Role;
import org.xwiki.model.reference.WikiReference;
import org.xwiki.security.authorization.Right;

/**
 * Temporary interface to access XWiki information without depending on oldcore.
 *
 * @version $Id: f16fb56bf279367c57f2f7a54ac5feaa4f861e8c $
 * @since 4.0M2
 */
@Role
public interface XWikiBridge
{
    /**
     * @return the wiki reference of the main wiki.
     */
    WikiReference getMainWikiReference();

    /**
     * @return {@code true} if the XWiki server is in read-only maintenance mode.
     */
    boolean isWikiReadOnly();

    /**
     * Check if authentication is always required for a given right.
     *
     * @param right the right to be checked.
     * @return {@code true} if authentication is needed.
     * @since 6.1RC1
     */
    boolean needsAuthentication(Right right);
}

==> xwiki-platform-security-api-10.11.8-sources.jar: org/xwiki/security/internal/XWikiBridge.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.security.internal;

import org.xwiki.component.annotation.Role;
import org.xwiki.model.reference.EntityReference;
import org.xwiki.model.reference.WikiReference;
import org.xwiki.security.authorization.Right;
import org.xwiki.stability.Unstable;

/**
 * Temporary interface to access XWiki information without depending on oldcore.
 *
 * @version $Id: c8a2da9ae098c54e2fa97852ff020a5020222182 $
 * @since 4.0M2
 */
@Role
public interface XWikiBridge
{
    /**
     * @return the wiki reference of the main wiki.
     */
    WikiReference getMainWikiReference();

    /**
     * @return {@code true} if the XWiki server is in read-only maintenance mode.
     */
    boolean isWikiReadOnly();

    /**
     * Check if authentication is always required for a given right.
     *
     * @param right the right to be checked.
     * @return {@code true} if authentication is needed.
     * @since 6.1RC1
     */
    boolean needsAuthentication(Right right);

    /**
     * Right now the security module logic only works with DOCUMENT based reference so PAGE reference need to be
     * converted.
     * 
     * @param reference the reference
     * @return the compatible reference
     * @since 10.6RC1
     */
    @Unstable
    EntityReference toCompatibleEntityReference(EntityReference reference);
}
